pesepay library
Pesepay helps businesses in Africa get paid by anyone, anywhere in the world
Classes
- Amount
- ApiConfig
- Currency
- Customer
- PaymentMethod
- Pesepay
- A simple library that wraps Pesepay payment gateway functionalities for the purposes of simplicity and accessibility for developers.
- RequiredField
- SeamlessTransaction
- Transaction
- TransactionResponse
- TransactionResponseStreamManager
- Transaction Status Stream Manager Inspired by paynow
Extensions
- AmountPatterns on Amount
- Adds pattern-matching-related methods to Amount.
- CurrencyPatterns on Currency
- Adds pattern-matching-related methods to Currency.
- CustomerPatterns on Customer
- Adds pattern-matching-related methods to Customer.
- PaymentMethodPatterns on PaymentMethod
- Adds pattern-matching-related methods to PaymentMethod.
- RequiredFieldPatterns on RequiredField
- Adds pattern-matching-related methods to RequiredField.
- SeamlessTransactionPatterns on SeamlessTransaction
- Adds pattern-matching-related methods to SeamlessTransaction.
- TransactionPatterns on Transaction
- Adds pattern-matching-related methods to Transaction.
- TransactionResponsePatterns on TransactionResponse
- Adds pattern-matching-related methods to TransactionResponse.
Functions
-
dioErrorToPesepayException(
DioError error, StackTrace stackTrace) → PesepayException